@@ -1,7 +1,7 @@
 /*@z05.c:Read Definitions:ReadFontDef()@**************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -242,6 +242,10 @@ static void ReadTokenList(OBJECT token, OBJECT res)
     case FORCE_CROSS:
     case NULL_CLOS:
     case PAGE_LABEL:
+    case BEGIN_HEADER:
+    case END_HEADER:
+    case SET_HEADER:
+    case CLEAR_HEADER:
     case ONE_COL:
     case ONE_ROW:
     case WIDE:
@@ -283,10 +287,13 @@ static void ReadTokenList(OBJECT token, OBJECT res)
     case BREAK:
     case UNDERLINE:
     case COLOUR:
+    case OUTLINE:
     case LANGUAGE:
     case CURR_LANG:
     case CURR_FAMILY:
     case CURR_FACE:
+    case CURR_YUNIT:
+    case CURR_ZUNIT:
     case COMMON:
     case RUMP:
     case MELD:
