@@ -1,7 +1,7 @@
 /*@z07.c:Object Service:SplitIsDefinite(), DisposeObject()@*******************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -177,6 +177,10 @@ OBJECT CopyObject(OBJECT x, FILE_POS *pos)
     case PAGE_LABEL:
     case CROSS:
     case FORCE_CROSS:
+    case BEGIN_HEADER:
+    case END_HEADER:
+    case SET_HEADER:
+    case CLEAR_HEADER:
     case ONE_COL:
     case ONE_ROW:
     case WIDE:
@@ -218,10 +222,13 @@ OBJECT CopyObject(OBJECT x, FILE_POS *pos)
     case BREAK:
     case UNDERLINE:
     case COLOUR:
+    case OUTLINE:
     case LANGUAGE:
     case CURR_LANG:
     case CURR_FAMILY:
     case CURR_FACE:
+    case CURR_YUNIT:
+    case CURR_ZUNIT:
     case COMMON:
     case RUMP:
     case MELD:
@@ -296,6 +303,7 @@ OBJECT CopyObject(OBJECT x, FILE_POS *pos)
     default:
     
       assert1(FALSE, "CopyObject:", Image(type(x)));
+      res = nilobj;
       break;
 
   } /* end switch */
@@ -334,6 +342,10 @@ OBJECT InsertObject(OBJECT x, OBJECT *ins, STYLE *style)
 
 
     case NULL_CLOS:
+    case BEGIN_HEADER:
+    case END_HEADER:
+    case SET_HEADER:
+    case CLEAR_HEADER:
     case HEAD:
     case CROSS:
     case FORCE_CROSS:
