@@ -1,7 +1,7 @@
 /*@z12.c:Size Finder:MinSize()@***********************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -28,6 +28,8 @@
 /*                                                                           */
 /*****************************************************************************/
 #include "externs.h"
+#define line_breaker(g)							\
+  (vspace(g) > 0 || (units(gap(g)) == FRAME_UNIT && width(gap(g)) > FR))
 #define IG_LOOKING	0
 #define IG_NOFILE	1
 #define IG_BADFILE	2
@@ -107,12 +109,12 @@ static BOOLEAN BuildSpanner(OBJECT x)
       Error(12, 11, "%s symbol out of place", FATAL, &fpos(x), Image(type(x)));
     }
     assert(type(prnt) == ROW_THR, "BuildSpanner: type(prnt)!");
-    spanner_sized(hspanner) = 0;
+    spanner_sized(hspanner) = spanner_fixed(hspanner) = 0;
     spanner_count(hspanner) = 1;
     end_link = NextDown(UpDim(x, ROWM));
     for( link = NextDown(UpDim(x, ROWM)); link != prnt; link = NextDown(link) )
     { Child(y, link);
-      debug2(DSF, DD, "  examining ver %s %s", Image(type(y)), y);
+      debug2(DSF, DD, "  examining ver %s %s", Image(type(y)), EchoObject(y));
       if( type(y) == HSPAN )
         end_link = NextDown(link);
       else if( type(y) == START_HVSPAN || type(y) == START_HSPAN ||
@@ -156,7 +158,7 @@ static BOOLEAN BuildSpanner(OBJECT x)
     /* @StartHVSpan or @StartHSpan or @StartVSpan or @HSpan or end of column */
     Parent(prnt, UpDim(x, COLM));
     assert(type(prnt) == COL_THR, "BuildSpanner: type(prnt)!");
-    spanner_sized(vspanner) = 0;
+    spanner_sized(vspanner) = spanner_fixed(vspanner) = 0;
     spanner_count(vspanner) = 1;
     end_link = NextDown(UpDim(x, COLM));
     for( link = NextDown(UpDim(x, COLM)); link != prnt; link = NextDown(link) )
@@ -322,7 +324,7 @@ void SpannerAvailableSpace(OBJECT y, int dim, FULL_LENGTH *resb,
 
 OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
 { OBJECT y, z, link, prev, t, g, full_name;
-  FULL_LENGTH b, f, dble_fwd, llx, lly, urx, ury; int status;
+  FULL_LENGTH b, f, dble_fwd, llx, lly, urx, ury; int status, read_status;
   float fllx, flly, furx, fury;
   BOOLEAN dble_found, found, will_expand, first_line, cp;
   FILE *fp;  FULL_CHAR buff[MAX_BUFF];
@@ -586,6 +588,15 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
       break;
 
 
+    case END_HEADER:
+    case CLEAR_HEADER:
+
+      back(x, dim) = fwd(x, dim) = 0;
+      break;
+
+
+    case BEGIN_HEADER:
+    case SET_HEADER:
     case PLAIN_GRAPHIC:
     case GRAPHIC:
     
@@ -793,6 +804,90 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
 
 
     case ACAT:
+
+      if( fill_style(save_style(x)) == FILL_OFF )
+      { OBJECT new_line, g, z, res;  BOOLEAN jn;
+
+	/* convert ACAT to VCAT of lines if more than one line */
+	/* first, compress all ACAT children                   */
+	for( link = x;  NextDown(link) != x;  link = NextDown(link) )
+	{ Child(y, NextDown(link));
+	  if( type(y) == ACAT )
+	  {
+	    TransferLinks(Down(y), y, NextDown(link));
+	    DisposeChild(Up(y));
+	    link = PrevDown(link);
+	  }
+	}
+
+	/* check each definite subobject in turn for a linebreak preceding */
+	FirstDefinite(x, link, y, jn);
+	if( link != x )
+	{
+	  res = nilobj;
+	  NextDefiniteWithGap(x,  link, y, g, jn);
+	  while( link != x )
+	  {
+	    /* check whether we need to break the paragraph here at g */
+	    if( mode(gap(g)) != NO_MODE && line_breaker(g) )
+	    {
+	      /* if this is our first break, build res */
+	      if( res == nilobj )
+	      {
+		New(res, VCAT);
+		adjust_cat(res) = FALSE;
+		ReplaceNode(res, x);
+	      }
+
+	      /* make new line of stuff up to g and append it to res */
+	      New(new_line, ACAT);
+	      TransferLinks(NextDown(x), Up(g), new_line);
+	      StyleCopy(save_style(new_line), save_style(x));
+	      Link(res, new_line);
+
+	      /* may need to insert space at start of remainder */
+	      if( hspace(g) > 0 )
+	      {
+		/* make an empty word to occupy the first spot */
+		z = MakeWord(WORD, STR_EMPTY, &fpos(g));
+		word_font(z) = font(save_style(x));
+		word_colour(z) = colour(save_style(x));
+		word_outline(z) = outline(save_style(x));
+		word_language(z) = language(save_style(x));
+		word_hyph(z) = hyph_style(save_style(x)) == HYPH_ON;
+		underline(z) = UNDER_OFF;
+		Link(Down(x), z);
+
+		/* follow the empty word with a gap of the right width */
+		New(z, GAP_OBJ);
+		hspace(z) = hspace(g);
+		vspace(z) = 0;
+		underline(z) = UNDER_OFF;
+		GapCopy(gap(z), space_gap(save_style(x)));
+		width(gap(z)) *= hspace(z);
+		Link(NextDown(Down(x)), z);
+	      }
+
+	      /* append a gap to res (recycle g) */
+	      MoveLink(Up(g), res, PARENT);
+	      GapCopy(gap(g), line_gap(save_style(x)));
+	      width(gap(g)) *= find_max(1, vspace(g));
+
+	    }
+	    NextDefiniteWithGap(x, link, y, g, jn);
+	  }
+
+	  /* at end of loop, if we have a res, leftover last line is linked */
+	  if( res != nilobj )
+	  {
+	    Link(res, x);
+	    x = res;
+	  }
+	}
+      }
+      /* *** NB NO BREAK *** */
+
+
     case HCAT:
     case VCAT:
     
@@ -842,6 +937,7 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
 		    mode(gap(g)) == EDGE_MODE && !mark(gap(g)) &&
 		    word_font(prev) == word_font(y) &&
 		    word_colour(prev) == word_colour(y) &&
+		    word_outline(prev) == word_outline(y) &&
 		    word_language(prev) == word_language(y) &&
 		    underline(prev) == underline(y) &&
 		    NextDown(NextDown(Up(prev))) == link
@@ -858,6 +954,7 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
 		  y = MakeWordTwo(typ, string(prev), string(y), &fpos(prev));
 		  word_font(y) = word_font(prev);
 		  word_colour(y) = word_colour(prev);
+		  word_outline(y) = word_outline(prev);
 		  word_language(y) = word_language(prev);
 		  word_hyph(y) = word_hyph(prev);
 		  underline(y) = underline(prev);
@@ -1123,8 +1220,17 @@ OBJECT MinSize(OBJECT x, int dim, OBJECT *extras)
       fp = OpenIncGraphicFile(string(y), type(x), &full_name, &fpos(y), &cp);
       if( fp == NULL )  status = IG_NOFILE;
       first_line = TRUE;
+      /* ***
       while( status == IG_LOOKING && StringFGets(buff, MAX_BUFF, fp) != NULL )
+      *** */
+      while( status == IG_LOOKING )
       {
+	read_status = fscanf(fp, "%[^\n\r]%*c", (char *) buff);
+	if( read_status == 0 || read_status == EOF )
+	{
+	  /* end of input and no luck */
+	  break;
+	}
 	if( first_line && !StringBeginsWith(buff, AsciiToFull("%!")) )
 	  status = IG_BADFILE;
 	else
