@@ -1,7 +1,7 @@
 /*@z18.c:Galley Transfer:Declarations@****************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -80,6 +80,7 @@ void TransferInit(OBJECT InitEnv)
   small_caps(InitialStyle)      = SMALL_CAPS_OFF;
   font(InitialStyle)            = 0;			/* i.e. undefined    */
   colour(InitialStyle)          = 0;			/* i.e. undefined    */
+  outline(InitialStyle)         = FALSE;		/* i.e. not outlined */
   language(InitialStyle)        = 0;			/* i.e. undefined    */
   yunit(InitialStyle)           = 0;			/* i.e. zero         */
   zunit(InitialStyle)           = 0;			/* i.e. zero         */
@@ -89,7 +90,7 @@ void TransferInit(OBJECT InitEnv)
   /* construct destination for root galley */
   New(up_hd, HEAD);
   force_gall(up_hd) = FALSE;
-  actual(up_hd) = enclose_obj(up_hd) = limiter(up_hd) = nilobj;
+  actual(up_hd) = enclose_obj(up_hd) = headers(up_hd) = limiter(up_hd) = nilobj;
   opt_components(up_hd) = opt_constraints(up_hd) = nilobj;
   gall_dir(up_hd) = ROWM;
   New(dest_index, RECEIVING);
@@ -107,6 +108,7 @@ void TransferInit(OBJECT InitEnv)
   New(root_galley, HEAD);
   force_gall(root_galley) = FALSE;
   enclose_obj(root_galley) = limiter(root_galley) = nilobj;
+  headers(root_galley) = nilobj;
   opt_components(root_galley) = opt_constraints(root_galley) = nilobj;
   gall_dir(root_galley) = ROWM;
   FposCopy(fpos(root_galley), *no_fpos);
@@ -197,6 +199,7 @@ OBJECT TransferBegin(OBJECT x)
   AttachEnv(env, x);
   SetTarget(hd);
   enclose_obj(hd) = (has_enclose(actual(hd)) ? BuildEnclose(hd) : nilobj);
+  headers(hd) = nilobj;
 
   /* search for destination for hd and release it */
   Link(Up(target), index);
@@ -295,7 +298,7 @@ void TransferComponent(OBJECT x)
   /* make the component into a galley */
   New(hd, HEAD);
   force_gall(hd) = FALSE;
-  enclose_obj(hd) = limiter(hd) = nilobj;
+  enclose_obj(hd) = limiter(hd) = headers(hd) = nilobj;
   opt_components(hd) = opt_constraints(hd) = nilobj;
   gall_dir(hd) = ROWM;
   FposCopy(fpos(hd), fpos(x));
@@ -398,7 +401,7 @@ void TransferEnd(OBJECT x)
   /* make the component into a galley */
   New(hd, HEAD);  FposCopy(fpos(hd), fpos(x));
   force_gall(hd) = FALSE;
-  enclose_obj(hd) = limiter(hd) = nilobj;
+  enclose_obj(hd) = limiter(hd) = headers(hd) = nilobj;
   opt_components(hd) = opt_constraints(hd) = nilobj;
   gall_dir(hd) = ROWM;
   actual(hd) = whereto(hd) = ready_galls(hd) = nilobj;
