@@ -1,7 +1,7 @@
 /*@z29.c:Symbol Table:Declarations, hash()@***********************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -304,7 +304,7 @@ unsigned xpredefined, OBJECT xenclosing, OBJECT xbody)
   uses_count(s)  = 0;
   dirty(s)       = FALSE;
   if( enclosing(s) != nilobj && type(enclosing(s)) == NPAR )
-    dirty(enclosing(s)) = TRUE;
+    dirty(s) = dirty(enclosing(s)) = TRUE;
 
   has_par(s)     = FALSE;
   has_lpar(s)    = FALSE;
