@@ -1,7 +1,7 @@
 /*@z41.c:Object Input-Output:AppendToFile, ReadFromFile@**********************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.17)                       */
-/*  COPYRIGHT (C) 1991, 1999 Jeffrey H. Kingston                             */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.20)                       */
+/*  COPYRIGHT (C) 1991, 2000 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
 /*  Basser Department of Computer Science                                    */
@@ -487,6 +487,10 @@ static void WriteObject(OBJECT x, int outer_prec, int *linecount, FILE_NUM fnum)
 
     case NULL_CLOS:	name = KW_NULL;		goto SETC;
     case PAGE_LABEL:	name = KW_PAGE_LABEL;	goto SETC;
+    case BEGIN_HEADER:	name = KW_BEGIN_HEADER;	goto SETC;
+    case END_HEADER:	name = KW_END_HEADER;	goto SETC;
+    case SET_HEADER:	name = KW_SET_HEADER;	goto SETC;
+    case CLEAR_HEADER:	name = KW_CLEAR_HEADER;	goto SETC;
     case ONE_COL:	name = KW_ONE_COL;	goto SETC;
     case ONE_ROW:	name = KW_ONE_ROW;	goto SETC;
     case WIDE:		name = KW_WIDE;		goto SETC;
@@ -526,10 +530,13 @@ static void WriteObject(OBJECT x, int outer_prec, int *linecount, FILE_NUM fnum)
     case BREAK:		name = KW_BREAK;	goto SETC;
     case UNDERLINE:	name = KW_UNDERLINE;	goto SETC;
     case COLOUR:	name = KW_COLOUR;	goto SETC;
+    case OUTLINE:	name = KW_OUTLINE;	goto SETC;
     case LANGUAGE:	name = KW_LANGUAGE;	goto SETC;
     case CURR_LANG:	name = KW_CURR_LANG;	goto SETC;
     case CURR_FAMILY:	name = KW_CURR_FAMILY;	goto SETC;
     case CURR_FACE:	name = KW_CURR_FACE;	goto SETC;
+    case CURR_YUNIT:	name = KW_CURR_YUNIT;	goto SETC;
+    case CURR_ZUNIT:	name = KW_CURR_ZUNIT;	goto SETC;
     case COMMON:	name = KW_COMMON;	goto SETC;
     case RUMP:		name = KW_RUMP;		goto SETC;
     case MELD:		name = KW_MELD;		goto SETC;
